summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDShaligram <DShaligram@c06c8d41-db1a-0410-9941-cceddc491573>2006-08-15 10:45:51 +0000
committerDShaligram <DShaligram@c06c8d41-db1a-0410-9941-cceddc491573>2006-08-15 10:45:51 +0000
commit0d9cfab608b3ed662b6fc687ba94008e623088d1 (patch)
tree71c56f255eb5d7872123ba7b9610d04a8133f87b
parentaa6e0f9a964e4aeb51e4b4a2b3e22d594a51f78d (diff)
downloadcrawl-ref-0d9cfab608b3ed662b6fc687ba94008e623088d1.tar.gz
crawl-ref-0d9cfab608b3ed662b6fc687ba94008e623088d1.zip
r28@calamity: dshaligram | 2006-08-15 16:03:39 +051800
* Updated README for Stone Soup * Tweaked shield blocking chances to increase the role of shield skill (beam.cc and fight.cc) * Changed title to Dungeon Crawl Stone Soup (chardump.cc and command.cc) and changed version to 0.1 (version.h) to avoid confusion with regular Crawl and crawl-ref itself. * Added warp weapon spell (item_use.cc, spells2.cc, spl-book.cc). * Fixed makefile.mgw to use correct Lua library names and compile libw32c.cc correctly. git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/branches/stone_soup@17 c06c8d41-db1a-0410-9941-cceddc491573
-rw-r--r--crawl-ref/README.crawl_ref19
-rw-r--r--crawl-ref/source/beam.cc15
-rw-r--r--crawl-ref/source/chardump.cc2
-rw-r--r--crawl-ref/source/command.cc2
-rw-r--r--crawl-ref/source/fight.cc15
-rw-r--r--crawl-ref/source/item_use.cc6
-rw-r--r--crawl-ref/source/itemname.cc7
-rw-r--r--crawl-ref/source/makefile.mgw8
-rw-r--r--crawl-ref/source/spells2.cc6
-rw-r--r--crawl-ref/source/spl-book.cc2
-rw-r--r--crawl-ref/source/version.h2
11 files changed, 57 insertions, 27 deletions
diff --git a/crawl-ref/README.crawl_ref b/crawl-ref/README.crawl_ref
index 776e48758b..e52dd802de 100644
--- a/crawl-ref/README.crawl_ref
+++ b/crawl-ref/README.crawl_ref
@@ -1,12 +1,17 @@
-Dungeon Crawl Reference Notes
-------- ----- --------- -----
+Dungeon Crawl (Stone Soup) Notes
+------- ----- ------ ----- -----
-What you have downloaded is *not* Linley's Dungeon Crawl. It's a parallel
-effort, currently not quite a fork.
+What you have downloaded is *not* Linley's Dungeon Crawl. This is a somewhat
+experimental branch of the Dungeon Crawl Reference project (codenamed Stone
+Soup). Note that this is a branch, and is NOT the official Dungeon Crawl
+Reference.
-The goal of this version is to provide a stable base platform for
-experimentation and patches, and to fill in the gaps during times when
-Dungeon Crawl's main maintainer is not available.
+The goal of this version is to build on Dungeon Crawl Reference (which aims to
+be the stable base platform for experimentation and patches, and to fill in the
+gaps during times when Dungeon Crawl's main maintainer is not available) with
+good features drawn from sources such as Brent Ross' 4.1.2 alpha, and ideas
+from the community of Dungeon Crawl players and to keep development on Dungeon
+Crawl moving without destablizing game balance.
Please do not send bug reports for this code to the main Dungeon Crawl
maintainers -- the odds are good that the code that's causing you problems
diff --git a/crawl-ref/source/chardump.cc b/crawl-ref/source/chardump.cc
index 5fd7b18f57..a8638c1118 100644
--- a/crawl-ref/source/chardump.cc
+++ b/crawl-ref/source/chardump.cc
@@ -1025,7 +1025,7 @@ bool dump_char( const char fname[30], bool show_prices ) // $$$ a try block?
// start with enough room for 100 80 character lines
text.reserve(100 * 80);
- text += " Dungeon Crawl version " VERSION " character file.";
+ text += " Dungeon Crawl Stone Soup version " VERSION " character file.";
text += EOL;
text += EOL;
diff --git a/crawl-ref/source/command.cc b/crawl-ref/source/command.cc
index 25644bdb0b..145edf2e77 100644
--- a/crawl-ref/source/command.cc
+++ b/crawl-ref/source/command.cc
@@ -64,7 +64,7 @@ static const char *features[] = {
void version(void)
{
- mpr( "This is Dungeon Crawl " VERSION " (Last build " BUILD_DATE ")." );
+ mpr( "This is Dungeon Crawl Stone Soup " VERSION " (Last build " BUILD_DATE ")." );
std::string feats = "Features: ";
for (int i = 1, size = sizeof features / sizeof *features; i < size; ++i)
diff --git a/crawl-ref/source/fight.cc b/crawl-ref/source/fight.cc
index 42cb60edf5..d8e10dd5fd 100644
--- a/crawl-ref/source/fight.cc
+++ b/crawl-ref/source/fight.cc
@@ -2020,16 +2020,23 @@ void monster_attack(int monster_attacking)
// Factors against blocking
// [dshaligram] Scaled back HD effect to 50% of previous, reduced
// shield_blocks multiplier to 5.
- const int con_block = 15 + attacker->hit_dice / 2
- + (5 * you.shield_blocks * you.shield_blocks);
+ const int con_block =
+ random2(15 + attacker->hit_dice / 2
+ + (5 * you.shield_blocks * you.shield_blocks));
- // Factors for blocking
+ // Factors for blocking:
+ // [dshaligram] Increased dex weight from .2 to .3333, added weighting
+ // for shields skill.
const int pro_block = player_shield_class() + (random2(you.dex) / 5);
+ random2(player_shield_class())
+ + (random2(you.dex) / 3)
+ + (random2(skill_bump(SK_SHIELDS)) / 3)
+ - 1;
if (!you.paralysis && !you_are_delayed() && !you.conf
&& player_monster_visible( attacker )
&& player_shield_class() > 0
- && random2(con_block) <= random2(pro_block))
+ && con_block <= pro_block)
{
you.shield_blocks++;
diff --git a/crawl-ref/source/item_use.cc b/crawl-ref/source/item_use.cc
index a153dbf6a3..a2dbfe1fdd 100644
--- a/crawl-ref/source/item_use.cc
+++ b/crawl-ref/source/item_use.cc
@@ -2543,11 +2543,15 @@ static bool affix_weapon_enchantment( void )
break;
case SPWPN_DISTORTION:
+ // [dshaligram] Attempting to fix a distortion brand gets you a free
+ // distortion effect, and no permabranding. Sorry, them's the breaks.
strcat(info, " twongs alarmingly.");
mpr(info);
// from unwield_item
- miscast_effect( SPTYP_TRANSLOCATION, 9, 90, 100, "a distortion effect" );
+ miscast_effect( SPTYP_TRANSLOCATION, 9, 90, 100,
+ "a distortion effect" );
+ success = false;
break;
default:
diff --git a/crawl-ref/source/itemname.cc b/crawl-ref/source/itemname.cc
index 4531bded9e..43c782bbb5 100644
--- a/crawl-ref/source/itemname.cc
+++ b/crawl-ref/source/itemname.cc
@@ -2660,7 +2660,12 @@ void init_properties(void)
prop[OBJ_WEAPONS][WPN_KATANA][PWPN_DAMAGE] = 13;
prop[OBJ_WEAPONS][WPN_KATANA][PWPN_HIT] = 4;
prop[OBJ_WEAPONS][WPN_KATANA][PWPN_SPEED] = 13;
- mss[OBJ_WEAPONS][WPN_KATANA] = 160;
+ mss[OBJ_WEAPONS][WPN_KATANA] = 200;
+
+ prop[OBJ_WEAPONS][WPN_BLESSED_BLADE][PWPN_DAMAGE] = 14;
+ prop[OBJ_WEAPONS][WPN_BLESSED_BLADE][PWPN_HIT] = -3;
+ prop[OBJ_WEAPONS][WPN_BLESSED_BLADE][PWPN_SPEED] = 14;
+ mss[OBJ_WEAPONS][WPN_BLESSED_BLADE] = 160;
prop[OBJ_WEAPONS][WPN_EXECUTIONERS_AXE][PWPN_DAMAGE] = 20;
prop[OBJ_WEAPONS][WPN_EXECUTIONERS_AXE][PWPN_HIT] = -4;
diff --git a/crawl-ref/source/makefile.mgw b/crawl-ref/source/makefile.mgw
index 499d3e22d2..312dcd705d 100644
--- a/crawl-ref/source/makefile.mgw
+++ b/crawl-ref/source/makefile.mgw
@@ -13,10 +13,12 @@ OS_TYPE = WIN32CONSOLE
CFLAGS = -Wall -Wwrite-strings -Wstrict-prototypes \
-Wmissing-prototypes -Wmissing-declarations \
-D$(OS_TYPE) $(EXTRA_FLAGS)
+OBJECTS := $(OBJECTS) libw32c.o
+
LDFLAGS =
INSTALLDIR = .
#LIB = -lcurso -lpano
-LIB = -lwinmm -static -lpcre -lluacore -lluastd
+LIB = -lwinmm -static -lpcre -llua -llualib
all: $(APPNAME)
@@ -37,8 +39,8 @@ distclean:
$(DELETE) *.0*
$(DELETE) *.lab
-$(APPNAME): $(OBJECTS) libw32c.o
- ${CXX} ${LDFLAGS} $(INCLUDES) $(CFLAGS) $(OBJECTS) libw32c.o -o $(APPNAME) $(LIB)
+$(APPNAME): $(OBJECTS)
+ ${CXX} ${LDFLAGS} $(INCLUDES) $(CFLAGS) $(OBJECTS) -o $(APPNAME) $(LIB)
strip $(APPNAME)
debug: $(OBJECTS)
diff --git a/crawl-ref/source/spells2.cc b/crawl-ref/source/spells2.cc
index 45bd01391c..3f4ccaf418 100644
--- a/crawl-ref/source/spells2.cc
+++ b/crawl-ref/source/spells2.cc
@@ -622,7 +622,11 @@ bool brand_weapon(int which_brand, int power)
// This brand is insanely powerful, this isn't even really
// a start to balancing it, but it needs something. -- bwr
- miscast_effect(SPTYP_TRANSLOCATION, 9, 90, 100, "a distortion effect");
+ // [dshaligram] At level 7 it's costly enough to experiment
+ // with removing the miscast effect. We may need to revise the spell
+ // to level 8 or 9. XXX.
+ // miscast_effect(SPTYP_TRANSLOCATION,
+ // 9, 90, 100, "a distortion effect");
break;
case SPWPN_DUMMY_CRUSHING: //jmf: added for Maxwell's Silver Hammer
diff --git a/crawl-ref/source/spl-book.cc b/crawl-ref/source/spl-book.cc
index c1fc77d4dd..c6cd3cb185 100644
--- a/crawl-ref/source/spl-book.cc
+++ b/crawl-ref/source/spl-book.cc
@@ -413,12 +413,12 @@ static int spellbook_template_array[NUMBER_SPELLBOOKS][SPELLBOOK_SIZE] =
{0,
SPELL_CONTROLLED_BLINK,
SPELL_BANISHMENT,
+ SPELL_WARP_BRAND,
SPELL_DISPERSAL,
SPELL_PORTAL,
SPELL_NO_SPELL,
SPELL_NO_SPELL,
SPELL_NO_SPELL,
- SPELL_NO_SPELL,
},
// 32 - Book of Envenomations
{0,
diff --git a/crawl-ref/source/version.h b/crawl-ref/source/version.h
index 583e965a6c..cf8256e07d 100644
--- a/crawl-ref/source/version.h
+++ b/crawl-ref/source/version.h
@@ -38,7 +38,7 @@
/* ***********************************************************************
* called from: chardump - command - newgame
* *********************************************************************** */
-#define VERSION "4.0.0 beta 26 (crawl-ref)"
+#define VERSION "0.1 beta 1 (crawl-ref)"
// last updated 20feb2001 {GDL}
diff --git a/crawl-ref/source/beam.cc b/crawl-ref/source/beam.cc
index 669ba62e86..9bbead8675 100644
--- a/crawl-ref/source/beam.cc
+++ b/crawl-ref/source/beam.cc
@@ -3041,14 +3041,17 @@ static int affect_player( struct bolt &beam )
&& player_shield_class() > 0)
{
int exer = one_chance_in(3) ? 1 : 0;
- // [dshaligram] beam.hit multiplier lowererd to 3 - was 5.
- // In favour of blocking, dex multiplier changed to .5
- // (was .2).
- const int hit = random2( beam.hit * 3
- + 10 * you.shield_blocks * you.shield_blocks );
+ // [dshaligram] beam.hit multiplier lowererd to 2.5 - was 5.
+ // In favour of blocking, dex multiplier changed to .3333
+ // (was .2), added shield skill into the equation with a
+ // skill bump.
+ const int hit = random2( beam.hit * 5 / 2
+ + 5 * you.shield_blocks * you.shield_blocks );
const int block = random2(player_shield_class())
- + (random2(you.dex) / 2) - 1;
+ + (random2(you.dex) / 3)
+ + (random2(skill_bump(SK_SHIELDS)) / 3)
+ - 1;
if (hit < block)
{